@@ -95,6 +95,8 @@ typedef struct CLEANUP_STATE {
     const char *client_addr;		/* real or ersatz client */
     int     client_af;			/* real or ersatz client */
     const char *client_port;		/* real or ersatz client */
+    VSTRING *milter_ext_from;		/* externalized sender */
+    VSTRING *milter_ext_rcpt;		/* externalized recipient */
 } CLEANUP_STATE;
 
  /*
@@ -217,6 +219,11 @@ extern void cleanup_message(CLEANUP_STATE *, int, const char *, ssize_t);
   */
 extern void cleanup_extracted(CLEANUP_STATE *, int, const char *, ssize_t);
 
+ /*
+  * cleanup_final.c
+  */
+extern void cleanup_final(CLEANUP_STATE *);
+
  /*
   * cleanup_rewrite.c
   */
